ssanma: Calculate the optimal sample size allocation for a new two-arm trial when analyze it with the existing network
Description
This function calculates the optimal sample size allocation for each treatment group
with a fixed total sample size when planning a new two-arm trial
with binary outcome.