ssnma: Calculate the optimal sample sizes for a new two-arm trial when analyze it with the existing network
Description
This function calculates the optimal sample size for each treatment group to
achieve a pre-specified power when planning a new two-arm trial with
binary outcome.